@@ -15,21 +15,15 @@
  */
 
 #ifndef GLOBUS_DONT_DOCUMENT_INTERNAL
+
 /**
  * @file globus_gsi_authz_error.c
- * Globus GSI Authz Library
+ * @brief Globus GSI Authz Library
  * @author Sam Meder
- *
- * $RCSfile: globus_gsi_authz_error.c,v $
- * $Revision: 1.4 $
- * $Date: 2007/08/03 21:13:58 $
  */
-#endif
 
 #include "globus_gsi_authz_constants.h"
 
-#ifndef GLOBUS_DONT_DOCUMENT_INTERNAL
-
 char * 
 globus_l_gsi_authz_error_strings[GLOBUS_GSI_AUTHZ_ERROR_LAST] =
 {
